@@ -13,10 +13,10 @@ from configglue.schema import (
     StringOption,
     TupleOption,
 )
-from django import get_version
+from django import get_version, VERSION
 from django.conf import global_settings
-from django.conf.project_template import settings as project_settings
 
+from django_configglue.utils import get_project_settings
 
 # As in django.conf.global_settings:
 # This is defined here as a do-nothing function because we can't import
@@ -62,7 +62,7 @@ def derivate_django_schema(schema, exclude=None):
 
 
 class BaseDjangoSchema(Schema):
-    version = '1.0.2 final'
+    version = '1.0'
 
     # Sections
     class django(Section):
@@ -91,7 +91,7 @@ class BaseDjangoSchema(Schema):
             help="Tuple of IP addresses, as strings, that see debug comments, "
                  "when DEBUG is true and receive x-headers")
 
-        time_zone = StringOption(default='America/Chicago',
+        time_zone = StringOption(default='America/Chicago', null=True,
             help="Local time zone for this installation. All choices can be "
                  "found here: "
                  "http://en.wikipedia.org/wiki/List_of_tz_zones_by_name "
@@ -446,23 +446,6 @@ class BaseDjangoSchema(Schema):
             help="The profanities that will trigger a validation error in the "
                  "'hasNoProfanities' validator. All of these should be in "
                  "lowercase")
-        comments_banned_users_group = StringOption(null=True,
-            help="The group ID that designates which users are banned. "
-                 "Set to None if you're not using it")
-        comments_moderators_group = StringOption(null=True,
-            help="The group ID that designates which users can moderate "
-                 "comments. Set to None if you're not using it")
-        comments_sketchy_users_group = StringOption(null=True,
-            help="The group ID that designates the users whose comments "
-                 "should be e-mailed to MANAGERS. Set to None if you're not "
-                 "using it")
-        comments_first_few = IntOption(default=0,
-            help="The system will e-mail MANAGERS the first "
-                 "COMMENTS_FIRST_FEW comments by each user. Set this to 0 if "
-                 "you want to disable it")
-        banned_ips = TupleOption(
-            help="A tuple of IP addresses that have been banned from "
-                 "participating in various Django-powered features")
 
         ##################
         # AUTHENTICATION #
@@ -516,15 +499,15 @@ class BaseDjangoSchema(Schema):
         root_urlconf = StringOption(default='urls')
 
 
-Django112Base = derivate_django_schema(
+Django11Base = derivate_django_schema(
     BaseDjangoSchema, exclude=['jing_path'])
 
 
-class Django112Schema(Django112Base):
-    version = '1.1.2'
+class Django11Schema(Django11Base):
+    version = '1.1'
 
     # sections
-    class django(Django112Base.django):
+    class django(Django11Base.django):
 
         ################
         # CORE         #
@@ -595,11 +578,11 @@ class Django112Schema(Django112Base):
             ])
 
 
-class Django125Schema(Django112Schema):
-    version = '1.2.5'
+class Django12Schema(Django11Schema):
+    version = '1.2'
 
     # sections
-    class django(Django112Schema.django):
+    class django(Django11Schema.django):
 
         ################
         # CORE         #
@@ -743,6 +726,12 @@ class Django125Schema(Django112Schema):
                 'django.contrib.messages.context_processors.messages',
             ])
 
+        use_x_forwarded_host = BoolOption(default=False,
+            help="A boolean that specifies whether to use the "
+                 "X-Forwarded-Host header in preference to the Host header. "
+                 "This should only be enabled if a proxy which sets this "
+                 "header is in use.")
+
         format_module_path = StringOption(
             null=True, default=None,
             help="Python module path where user will place custom format "
@@ -815,6 +804,7 @@ class Django125Schema(Django112Schema):
             default=',',
             help="Thousand separator symbol")
 
+
         ##############
         # MIDDLEWARE #
         ##############
@@ -866,19 +856,16 @@ class Django125Schema(Django112Schema):
 
 
 Django13Base = derivate_django_schema(
-    Django125Schema, exclude=['cache_backend'])
+    Django12Schema,
+    exclude=[
+        'cache_backend',
+    ])
 
 
 class Django13Schema(Django13Base):
     version = '1.3'
 
-    # sections
     class django(Django13Base.django):
-
-        ################
-        # CORE         #
-        ################
-
         # update default value
         languages = ListOption(
             item=TupleOption(length=2),
@@ -1018,6 +1005,27 @@ class Django13Schema(Django13Base):
             help="The profanities that will trigger a validation error in the "
                  "'hasNoProfanities' validator. All of these should be in "
                  "lowercase")
+        comments_banned_users_group = StringOption(
+            null=True,
+            help="The group ID that designates which users are banned. "
+                 "Set to None if you're not using it")
+        comments_moderators_group = StringOption(
+            null=True,
+            help="The group ID that designates which users can moderate "
+                 "comments. Set to None if you're not using it")
+        comments_sketchy_users_group = StringOption(
+            null=True,
+            help="The group ID that designates the users whose comments "
+                 "should be e-mailed to MANAGERS. Set to None if you're not "
+                 "using it")
+        comments_first_few = IntOption(
+            default=0,
+            help="The system will e-mail MANAGERS the first "
+                 "COMMENTS_FIRST_FEW comments by each user. Set this to 0 if "
+                 "you want to disable it")
+        banned_ips = TupleOption(
+            help="A tuple of IP addresses that have been banned from "
+            "participating in various Django-powered features")
 
         ###########
         # LOGGING #
@@ -1105,24 +1113,550 @@ class Django13Schema(Django13Base):
         admin_media_prefix = StringOption(default='/static/admin/',
             help="URL prefix for admin media -- CSS, JavaScript and images. "
                  "Make sure to use a trailing slash. "
-                 "Examples: 'http://foo.com/media/', '/media/'")
+                 "Examples: 'htttp://foo.com/media/', '/media/'")
 
 
-class Django131Schema(Django13Schema):
-    version = '1.3.1'
+class Django136Schema(Django13Schema):
+    version = '1.3.6'
 
-    # sections
     class django(Django13Schema.django):
 
-        ################
-        # CORE         #
-        ################
+        allowed_hosts = ListOption(
+            item=StringOption(),
+            help="A list of strings representing the host/domain names "
+                 "that this Django site can serve. This is a security "
+                 "measure to prevent an attacker from poisoning caches and "
+                 "password reset emails with links to malicious hosts by "
+                 "submitting requests with a fake HTTP Host header, which is "
+                 "possible even under many seemingly-safe webserver "
+                 "configurations.")
 
-        use_x_forwarded_host = BoolOption(default=False,
-            help="A boolean that specifies whether to use the "
-                 "X-Forwarded-Host header in preference to the Host header. "
-                 "This should only be enabled if a proxy which sets this "
-                 "header is in use.")
+
+Django14Base = derivate_django_schema(
+    Django13Schema,
+    exclude=[
+        'admin_media_prefix',
+        'ignorable_404_starts',
+        'ignorable_404_ends',
+        'banned_ips',
+        'comments_banned_users_group',
+        'comments_moderators_group',
+        'comments_sketchy_users_group',
+        'comments_first_few',
+        'database_engine',
+        'database_host',
+        'database_name',
+        'database_options',
+        'database_password',
+        'database_port',
+        'database_user',
+        'test_database_charset',
+        'test_database_collation',
+        'test_database_name',
+    ])
+
+
+class Django14Schema(Django14Base):
+    version = '1.4'
+
+    class django(Django14Base.django):
+
+        wsgi_application = StringOption(
+            help="The full Python path of the WSGI application object"
+                 "that Django's built-in servers (e.g. runserver) will use.")
+
+        csrf_cookie_secure = BoolOption(
+            default=False,
+            help='Whether to use a secure cookie for the CSRF '
+                 'cookie. If this is set to True, the cookie will be marked '
+                 'as "secure," which means browsers may ensure that the '
+                 'cookie is only sent under an HTTPS connection.')
+
+        csrf_cookie_path = StringOption(
+            default='/',
+            help="The path set on the CSRF cookie. This should either "
+                 "match the URL path of your Django installation or be a "
+                 "parent of that path.")
+
+        secure_proxy_ssl_header = TupleOption(
+            length=2,
+            default=None,
+            help="A tuple representing a HTTP header/value combination "
+                 "that signifies a request is secure. This controls the "
+                 "behavior of the request object's is_secure() method.")
+
+        ignorable_404_urls = ListOption(
+            item=StringOption(),
+            help="List of compiled regular expression objects "
+                 "describing URLs that should be ignored when reporting HTTP "
+                 "404 errors via email (see Error reporting). Use this if "
+                 "your site does not provide a commonly requested file such "
+                 "as favicon.ico or robots.txt, or if it gets hammered by "
+                 "script kiddies.")
+
+        password_hashers = ListOption(
+            item=StringOption(),
+            help="This is a list of hashing algorithm classes that this "
+                 "Django installation supports. The first entry in this list "
+                 "(that is, settings.PASSWORD_HASHERS[0]) will be used to "
+                 "store passwords, and all the other entries are valid "
+                 "hashers that can be used to check existing passwords.",
+            default=[
+                'django.contrib.auth.hashers.PBKDF2PasswordHasher',
+                'django.contrib.auth.hashers.PBKDF2SHA1PasswordHasher',
+                'django.contrib.auth.hashers.BCryptPasswordHasher',
+                'django.contrib.auth.hashers.SHA1PasswordHasher',
+                'django.contrib.auth.hashers.MD5PasswordHasher',
+                'django.contrib.auth.hashers.UnsaltedMD5PasswordHasher',
+                'django.contrib.auth.hashers.CryptPasswordHasher',
+                ]
+            )
+
+        x_frame_options = StringOption(
+            default='SAMEORIGIN',
+            help="The default value for the X-Frame-Options header used "
+                 "by XFrameOptionsMiddleware.")
+
+        use_tz = BoolOption(
+            default=True,
+            help="A boolean that specifies if datetimes will be timezone-aware"
+                 " by default or not. If this is set to True, Django will use "
+                 "timezone-aware datetimes internally. Otherwise, Django will "
+                 "use naive datetimes in local time.")
+
+        default_exception_reporter_filter = StringOption(
+            default='django.views.debug.SafeExceptionReporterFilter',
+            help="Default exception reporter filter class to be used if none "
+                 "has been assigned to the HttpRequest instance yet.")
+
+        signing_backend = StringOption(
+            default='django.core.signing.TimestampSigner',
+            help="The backend used for signing cookies and other data.")
+
+        url_validator_user_agent = StringOption(
+            default=("Django/%s (https://www.djangoproject.com)" %
+                     get_version()),
+            help="The User-Agent string to use when checking for URL validity "
+                 "through the isExistingURL validator")
+
+        message_storage = StringOption(
+            default='django.contrib.messages.storage.fallback.'
+                'FallbackStorage',
+            help="Class to be used as messages backend")
+
+        logging = DictOption(
+            spec={
+                'version': IntOption(default=1),
+                'formatters': DictOption(
+                    item=DictOption(
+                        spec={
+                            'format': StringOption(null=True),
+                            'datefmt': StringOption(null=True)})),
+                'filters': DictOption(
+                    item=DictOption(
+                        spec={'name': StringOption()})),
+                'handlers': DictOption(
+                    item=DictOption(
+                        spec={
+                            'class': StringOption(fatal=True),
+                            'level': StringOption(),
+                            'formatter': StringOption(),
+                            'filters': StringOption()})),
+                'loggers': DictOption(
+                    item=DictOption(
+                        spec={
+                            'level': StringOption(),
+                            'propagate': BoolOption(),
+                            'filters': ListOption(item=StringOption()),
+                            'handlers': ListOption(item=StringOption()),
+                            })),
+                'root': DictOption(
+                    spec={
+                        'level': StringOption(),
+                        'filters': ListOption(item=StringOption()),
+                        'handlers': ListOption(item=StringOption()),
+                        }),
+                'incremental': BoolOption(default=False),
+                'disable_existing_loggers': BoolOption(default=False),
+            },
+            default={
+                'version': 1,
+                'disable_existing_loggers': False,
+                'filters': {
+                    'require_debug_false': {
+                        '()': 'django.utils.log.RequireDebugFalse',
+                    }
+                },
+                'handlers': {
+                    'mail_admins': {
+                       'level': 'ERROR',
+                       'filters': ['require_debug_false'],
+                       'class': 'django.utils.log.AdminEmailHandler'
+                    }
+                },
+                'loggers': {
+                    'django.request': {
+                        'handlers': ['mail_admins'],
+                        'level': 'ERROR',
+                        'propagate': True,
+                    },
+                }
+            },
+            help="The default logging configuration. This sends an email to "
+                 "the site admins on every HTTP 500 error. All other records "
+                 "are sent to the bit bucket.")
+
+        template_context_processors = ListOption(
+            item=StringOption(),
+            default=['django.contrib.auth.context_processors.auth',
+                     'django.core.context_processors.debug',
+                     'django.core.context_processors.i18n',
+                     'django.core.context_processors.media',
+                     'django.core.context_processors.static',
+                     'django.core.context_processors.tz',
+                     'django.contrib.messages.context_processors.messages',
+                     ],
+            help="List of processors used by RequestContext to populate the "
+                 "context. Each one should be a callable that takes the "
+                 "request object as its only parameter and returns a "
+                 "dictionary to add to the context")
+
+        languages = ListOption(
+            item=TupleOption(length=2),
+            default=[
+                ('ar', gettext_noop('Arabic')),
+                ('az', gettext_noop('Azerbaijani')),
+                ('bg', gettext_noop('Bulgarian')),
+                ('bn', gettext_noop('Bengali')),
+                ('bs', gettext_noop('Bosnian')),
+                ('ca', gettext_noop('Catalan')),
+                ('cs', gettext_noop('Czech')),
+                ('cy', gettext_noop('Welsh')),
+                ('da', gettext_noop('Danish')),
+                ('de', gettext_noop('German')),
+                ('el', gettext_noop('Greek')),
+                ('en', gettext_noop('English')),
+                ('en-gb', gettext_noop('British English')),
+                ('eo', gettext_noop('Esperanto')),
+                ('es', gettext_noop('Spanish')),
+                ('es-ar', gettext_noop('Argentinian Spanish')),
+                ('es-mx', gettext_noop('Mexican Spanish')),
+                ('es-ni', gettext_noop('Nicaraguan Spanish')),
+                ('et', gettext_noop('Estonian')),
+                ('eu', gettext_noop('Basque')),
+                ('fa', gettext_noop('Persian')),
+                ('fi', gettext_noop('Finnish')),
+                ('fr', gettext_noop('French')),
+                ('fy-nl', gettext_noop('Frisian')),
+                ('ga', gettext_noop('Irish')),
+                ('gl', gettext_noop('Galician')),
+                ('he', gettext_noop('Hebrew')),
+                ('hi', gettext_noop('Hindi')),
+                ('hr', gettext_noop('Croatian')),
+                ('hu', gettext_noop('Hungarian')),
+                ('id', gettext_noop('Indonesian')),
+                ('is', gettext_noop('Icelandic')),
+                ('it', gettext_noop('Italian')),
+                ('ja', gettext_noop('Japanese')),
+                ('ka', gettext_noop('Georgian')),
+                ('kk', gettext_noop('Kazakh')),
+                ('km', gettext_noop('Khmer')),
+                ('kn', gettext_noop('Kannada')),
+                ('ko', gettext_noop('Korean')),
+                ('lt', gettext_noop('Lithuanian')),
+                ('lv', gettext_noop('Latvian')),
+                ('mk', gettext_noop('Macedonian')),
+                ('ml', gettext_noop('Malayalam')),
+                ('mn', gettext_noop('Mongolian')),
+                ('nb', gettext_noop('Norwegian Bokmal')),
+                ('ne', gettext_noop('Nepali')),
+                ('nl', gettext_noop('Dutch')),
+                ('nn', gettext_noop('Norwegian Nynorsk')),
+                ('pa', gettext_noop('Punjabi')),
+                ('pl', gettext_noop('Polish')),
+                ('pt', gettext_noop('Portuguese')),
+                ('pt-br', gettext_noop('Brazilian Portuguese')),
+                ('ro', gettext_noop('Romanian')),
+                ('ru', gettext_noop('Russian')),
+                ('sk', gettext_noop('Slovak')),
+                ('sl', gettext_noop('Slovenian')),
+                ('sq', gettext_noop('Albanian')),
+                ('sr', gettext_noop('Serbian')),
+                ('sr-latn', gettext_noop('Serbian Latin')),
+                ('sv', gettext_noop('Swedish')),
+                ('sw', gettext_noop('Swahili')),
+                ('ta', gettext_noop('Tamil')),
+                ('te', gettext_noop('Telugu')),
+                ('th', gettext_noop('Thai')),
+                ('tr', gettext_noop('Turkish')),
+                ('tt', gettext_noop('Tatar')),
+                ('uk', gettext_noop('Ukrainian')),
+                ('ur', gettext_noop('Urdu')),
+                ('vi', gettext_noop('Vietnamese')),
+                ('zh-cn', gettext_noop('Simplified Chinese')),
+                ('zh-tw', gettext_noop('Traditional Chinese'))],
+            help="Languages we provide translations for, out of the box. "
+                 "The language name should be the utf-8 encoded local name "
+                 "for the language")
+
+        session_cookie_httponly = BoolOption(
+            default=True,
+            help="Whether to use the non-RFC standard htt pOnly flag (IE, "
+                 "FF3+, others)")
+
+        datetime_input_formats = ListOption(
+            item=StringOption(),
+            default=[
+                '%Y-%m-%d %H:%M:%S',     # '2006-10-25 14:30:59'
+                '%Y-%m-%d %H:%M:%S.%f',  # '2006-10-25 14:30:59.000200'
+                '%Y-%m-%d %H:%M',        # '2006-10-25 14:30'
+                '%Y-%m-%d',              # '2006-10-25'
+                '%m/%d/%Y %H:%M:%S',     # '10/25/2006 14:30:59'
+                '%m/%d/%Y %H:%M:%S.%f',  # '10/25/2006 14:30:59.000200'
+                '%m/%d/%Y %H:%M',        # '10/25/2006 14:30'
+                '%m/%d/%Y',              # '10/25/2006'
+                '%m/%d/%y %H:%M:%S',     # '10/25/06 14:30:59'
+                '%m/%d/%y %H:%M:%S.%f',  # '10/25/06 14:30:59.000200'
+                '%m/%d/%y %H:%M',        # '10/25/06 14:30'
+                '%m/%d/%y',              # '10/25/06'
+            ],
+            help="Default formats to be used when parsing dates and times "
+                "from input boxes, in order")
+
+
+class Django144Schema(Django14Schema):
+    version = '1.4.4'
+
+    class django(Django14Schema.django):
+
+        allowed_hosts = ListOption(
+            help="A list of strings representing the host/domain names "
+                 "that this Django site can serve. This is a security "
+                 "measure to prevent an attacker from poisoning caches and "
+                 "password reset emails with links to malicious hosts by "
+                 "submitting requests with a fake HTTP Host header, which is "
+                 "possible even under many seemingly-safe webserver "
+                 "configurations.")
+
+        languages = ListOption(
+            item=TupleOption(length=2),
+            default=[
+                ('af', gettext_noop('Afrikaans')),
+                ('ar', gettext_noop('Arabic')),
+                ('az', gettext_noop('Azerbaijani')),
+                ('bg', gettext_noop('Bulgarian')),
+                ('be', gettext_noop('Belarusian')),
+                ('bn', gettext_noop('Bengali')),
+                ('br', gettext_noop('Breton')),
+                ('bs', gettext_noop('Bosnian')),
+                ('ca', gettext_noop('Catalan')),
+                ('cs', gettext_noop('Czech')),
+                ('cy', gettext_noop('Welsh')),
+                ('da', gettext_noop('Danish')),
+                ('de', gettext_noop('German')),
+                ('el', gettext_noop('Greek')),
+                ('en', gettext_noop('English')),
+                ('en-gb', gettext_noop('British English')),
+                ('eo', gettext_noop('Esperanto')),
+                ('es', gettext_noop('Spanish')),
+                ('es-ar', gettext_noop('Argentinian Spanish')),
+                ('es-mx', gettext_noop('Mexican Spanish')),
+                ('es-ni', gettext_noop('Nicaraguan Spanish')),
+                ('es-ve', gettext_noop('Venezuelan Spanish')),
+                ('et', gettext_noop('Estonian')),
+                ('eu', gettext_noop('Basque')),
+                ('fa', gettext_noop('Persian')),
+                ('fi', gettext_noop('Finnish')),
+                ('fr', gettext_noop('French')),
+                ('fy-nl', gettext_noop('Frisian')),
+                ('ga', gettext_noop('Irish')),
+                ('gl', gettext_noop('Galician')),
+                ('he', gettext_noop('Hebrew')),
+                ('hi', gettext_noop('Hindi')),
+                ('hr', gettext_noop('Croatian')),
+                ('hu', gettext_noop('Hungarian')),
+                ('ia', gettext_noop('Interlingua')),
+                ('id', gettext_noop('Indonesian')),
+                ('is', gettext_noop('Icelandic')),
+                ('it', gettext_noop('Italian')),
+                ('ja', gettext_noop('Japanese')),
+                ('ka', gettext_noop('Georgian')),
+                ('kk', gettext_noop('Kazakh')),
+                ('km', gettext_noop('Khmer')),
+                ('kn', gettext_noop('Kannada')),
+                ('ko', gettext_noop('Korean')),
+                ('lb', gettext_noop('Luxembourgish')),
+                ('lt', gettext_noop('Lithuanian')),
+                ('lv', gettext_noop('Latvian')),
+                ('mk', gettext_noop('Macedonian')),
+                ('ml', gettext_noop('Malayalam')),
+                ('mn', gettext_noop('Mongolian')),
+                ('nb', gettext_noop('Norwegian Bokmal')),
+                ('ne', gettext_noop('Nepali')),
+                ('nl', gettext_noop('Dutch')),
+                ('nn', gettext_noop('Norwegian Nynorsk')),
+                ('pa', gettext_noop('Punjabi')),
+                ('pl', gettext_noop('Polish')),
+                ('pt', gettext_noop('Portuguese')),
+                ('pt-br', gettext_noop('Brazilian Portuguese')),
+                ('ro', gettext_noop('Romanian')),
+                ('ru', gettext_noop('Russian')),
+                ('sk', gettext_noop('Slovak')),
+                ('sl', gettext_noop('Slovenian')),
+                ('sq', gettext_noop('Albanian')),
+                ('sr', gettext_noop('Serbian')),
+                ('sr-latn', gettext_noop('Serbian Latin')),
+                ('sv', gettext_noop('Swedish')),
+                ('sw', gettext_noop('Swahili')),
+                ('ta', gettext_noop('Tamil')),
+                ('te', gettext_noop('Telugu')),
+                ('th', gettext_noop('Thai')),
+                ('tr', gettext_noop('Turkish')),
+                ('tt', gettext_noop('Tatar')),
+                ('udm', gettext_noop('Udmurt')),
+                ('uk', gettext_noop('Ukrainian')),
+                ('ur', gettext_noop('Urdu')),
+                ('vi', gettext_noop('Vietnamese')),
+                ('zh-cn', gettext_noop('Simplified Chinese')),
+                ('zh-tw', gettext_noop('Traditional Chinese')),],
+            help="Languages we provide translations for, out of the box. "
+                 "The language name should be the utf-8 encoded local name "
+                 "for the language")
+
+
+class Django145Schema(Django144Schema):
+    version = '1.4.5'
+
+    class django(Django144Schema.django):
+        languages = ListOption(
+            item=TupleOption(length=2),
+            default=[
+                ('ar', gettext_noop('Arabic')),
+                ('az', gettext_noop('Azerbaijani')),
+                ('bg', gettext_noop('Bulgarian')),
+                ('bn', gettext_noop('Bengali')),
+                ('bs', gettext_noop('Bosnian')),
+                ('ca', gettext_noop('Catalan')),
+                ('cs', gettext_noop('Czech')),
+                ('cy', gettext_noop('Welsh')),
+                ('da', gettext_noop('Danish')),
+                ('de', gettext_noop('German')),
+                ('el', gettext_noop('Greek')),
+                ('en', gettext_noop('English')),
+                ('en-gb', gettext_noop('British English')),
+                ('eo', gettext_noop('Esperanto')),
+                ('es', gettext_noop('Spanish')),
+                ('es-ar', gettext_noop('Argentinian Spanish')),
+                ('es-mx', gettext_noop('Mexican Spanish')),
+                ('es-ni', gettext_noop('Nicaraguan Spanish')),
+                ('et', gettext_noop('Estonian')),
+                ('eu', gettext_noop('Basque')),
+                ('fa', gettext_noop('Persian')),
+                ('fi', gettext_noop('Finnish')),
+                ('fr', gettext_noop('French')),
+                ('fy-nl', gettext_noop('Frisian')),
+                ('ga', gettext_noop('Irish')),
+                ('gl', gettext_noop('Galician')),
+                ('he', gettext_noop('Hebrew')),
+                ('hi', gettext_noop('Hindi')),
+                ('hr', gettext_noop('Croatian')),
+                ('hu', gettext_noop('Hungarian')),
+                ('id', gettext_noop('Indonesian')),
+                ('is', gettext_noop('Icelandic')),
+                ('it', gettext_noop('Italian')),
+                ('ja', gettext_noop('Japanese')),
+                ('ka', gettext_noop('Georgian')),
+                ('kk', gettext_noop('Kazakh')),
+                ('km', gettext_noop('Khmer')),
+                ('kn', gettext_noop('Kannada')),
+                ('ko', gettext_noop('Korean')),
+                ('lt', gettext_noop('Lithuanian')),
+                ('lv', gettext_noop('Latvian')),
+                ('mk', gettext_noop('Macedonian')),
+                ('ml', gettext_noop('Malayalam')),
+                ('mn', gettext_noop('Mongolian')),
+                ('nb', gettext_noop('Norwegian Bokmal')),
+                ('ne', gettext_noop('Nepali')),
+                ('nl', gettext_noop('Dutch')),
+                ('nn', gettext_noop('Norwegian Nynorsk')),
+                ('pa', gettext_noop('Punjabi')),
+                ('pl', gettext_noop('Polish')),
+                ('pt', gettext_noop('Portuguese')),
+                ('pt-br', gettext_noop('Brazilian Portuguese')),
+                ('ro', gettext_noop('Romanian')),
+                ('ru', gettext_noop('Russian')),
+                ('sk', gettext_noop('Slovak')),
+                ('sl', gettext_noop('Slovenian')),
+                ('sq', gettext_noop('Albanian')),
+                ('sr', gettext_noop('Serbian')),
+                ('sr-latn', gettext_noop('Serbian Latin')),
+                ('sv', gettext_noop('Swedish')),
+                ('sw', gettext_noop('Swahili')),
+                ('ta', gettext_noop('Tamil')),
+                ('te', gettext_noop('Telugu')),
+                ('th', gettext_noop('Thai')),
+                ('tr', gettext_noop('Turkish')),
+                ('tt', gettext_noop('Tatar')),
+                ('uk', gettext_noop('Ukrainian')),
+                ('ur', gettext_noop('Urdu')),
+                ('vi', gettext_noop('Vietnamese')),
+                ('zh-cn', gettext_noop('Simplified Chinese')),
+                ('zh-tw', gettext_noop('Traditional Chinese')),],
+            help="Languages we provide translations for, out of the box. "
+                 "The language name should be the utf-8 encoded local name "
+                 "for the language")
+
+
+Django15Base = derivate_django_schema(
+    Django145Schema,
+    exclude=[
+        'url_validator_user_agent',
+    ])
+
+
+class Django15Schema(Django15Base):
+    version = '1.5'
+
+    class django(Django15Base.django):
+
+        caches = DictOption(
+            item=UpperCaseDictOption(
+                spec={
+                    'backend': StringOption(),
+                    'location': StringOption()
+                }),
+            default={
+               'default': {
+                   'BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
+               }
+            })
+
+        auth_user_model = StringOption(
+            default='auth.User',
+            help="The model to use to represent a User.")
+
+        session_cache_alias = StringOption(
+            default='default',
+            help="If you're using cache-based session storage, this selects "
+                 " the cache to use.")
+
+        password_hashers = ListOption(
+            item=StringOption(),
+            help="This is a list of hashing algorithm classes that this "
+                 "Django installation supports. The first entry in this list "
+                 "(that is, settings.PASSWORD_HASHERS[0]) will be used to "
+                 "store passwords, and all the other entries are valid "
+                 "hashers that can be used to check existing passwords.",
+            default=[
+                'django.contrib.auth.hashers.PBKDF2PasswordHasher',
+                'django.contrib.auth.hashers.PBKDF2SHA1PasswordHasher',
+                'django.contrib.auth.hashers.BCryptPasswordHasher',
+                'django.contrib.auth.hashers.SHA1PasswordHasher',
+                'django.contrib.auth.hashers.MD5PasswordHasher',
+                'django.contrib.auth.hashers.UnsaltedSHA1PasswordHasher',
+                'django.contrib.auth.hashers.UnsaltedMD5PasswordHasher',
+                'django.contrib.auth.hashers.CryptPasswordHasher',
+                ])
 
 
 class DjangoSchemaFactory(object):
@@ -1143,6 +1677,7 @@ class DjangoSchemaFactory(object):
             return self._schemas[version]
 
         msg = "No schema registered for version %r" % version
+
         if strict:
             raise ValueError(msg)
         else:
@@ -1152,10 +1687,14 @@ class DjangoSchemaFactory(object):
         schema = self.build(version)
         return schema
 
-    def build(self, version_string=None, options=None):
+    def build(self, version_string=None, options=None,
+              BaseSchema=BaseDjangoSchema):
         if version_string is None:
             version_string = get_version()
+
         if options is None:
+            project_settings = get_project_settings()
+
             options = dict([(name.lower(), value) for (name, value) in
                 inspect.getmembers(global_settings) if name.isupper()])
             project_options = dict([(name.lower(), value) for (name, value) in
@@ -1168,10 +1707,18 @@ class DjangoSchemaFactory(object):
 
             options.update(project_options)
 
-        class DjangoSchema(Schema):
+        try:
+            base_version = '{0}.{1}'.format(*VERSION[:2])
+            BaseSchema = self.get(base_version)
+        except ValueError:
+            pass
+
+        section_base_class = getattr(BaseSchema, 'django', Section)
+
+        class DjangoSchema(BaseSchema):
             version = version_string
 
-            class django(Section):
+            class django(section_base_class):
                 pass
 
         def get_option_type(name, value):
@@ -1185,8 +1732,18 @@ class DjangoSchemaFactory(object):
                 unicode: StringOption,
             }
             if value is None:
+                # Special casing strange value, which by default is None but
+                # should be set to tuple.
+                if name == 'secure_proxy_ssl_header':
+                    return TupleOption(name=name, default=None)
+
                 return StringOption(name=name, default=value, null=True)
             else:
+                # Clean up values comming from the project template and having
+                # {{ }} substitutions in them.
+                if name in ('secret_key', 'wsgi_application'):
+                    value = ''
+
                 option_type = type_mappings[type(value)]
                 kwargs = {'name': name, 'default': value}
 
@@ -1217,8 +1774,9 @@ class DjangoSchemaFactory(object):
         for name, value in options.items():
             if name == '__CONFIGGLUE_PARSER__':
                 continue
-            option = get_option_type(name, value)
-            setattr(DjangoSchema.django, name, option)
+            if not hasattr(DjangoSchema.django, name):
+                option = get_option_type(name, value)
+                setattr(DjangoSchema.django, name, option)
 
         # register schema for it to be available during next query
         self.register(DjangoSchema, version_string)
@@ -1226,10 +1784,12 @@ class DjangoSchemaFactory(object):
 
 
 schemas = DjangoSchemaFactory()
-schemas.register(BaseDjangoSchema, '1.0.2 final')
-schemas.register(BaseDjangoSchema, '1.0.4')
-schemas.register(Django112Schema)
-schemas.register(Django112Schema, '1.1.4')
-schemas.register(Django125Schema)
+schemas.register(BaseDjangoSchema)
 schemas.register(Django13Schema)
-schemas.register(Django131Schema)
+schemas.register(Django136Schema)
+schemas.register(Django136Schema, '1.3.7')
+schemas.register(Django14Schema)
+schemas.register(Django144Schema)
+schemas.register(Django145Schema)
+schemas.register(Django15Schema)
+schemas.register(Django15Schema, '1.5.1')
